@@ -513,7 +513,6 @@ nm_vpn_plugin_ui_widget_interface_new (NMConnection *connection, GError **error)
 {
 	NMVpnEditor *object;
 	L2tpPluginUiWidgetPrivate *priv;
-	char *ui_file;
 	gboolean new = TRUE;
 	NMSettingVpn *s_vpn;
 
@@ -528,23 +527,14 @@ nm_vpn_plugin_ui_widget_interface_new (NMConnection *connection, GError **error)
 
 	priv = L2TP_PLUGIN_UI_WIDGET_GET_PRIVATE (object);
 
-	ui_file = g_strdup_printf ("%s/%s", UIDIR, "nm-l2tp-dialog.ui");
 	priv->builder = gtk_builder_new ();
 
 	gtk_builder_set_translation_domain (priv->builder, GETTEXT_PACKAGE);
 
-	if (!gtk_builder_add_from_file(priv->builder, ui_file, error)) {
-		g_warning (_("Couldn't load builder file: %s"),
-				error && *error ? (*error)->message : "(unknown)");
-		g_clear_error(error);
-		g_set_error(error, NMV_EDITOR_PLUGIN_ERROR, 0,
-					_("could not load required resources at %s"),
-					ui_file);
-		g_free(ui_file);
+	if (!gtk_builder_add_from_resource (priv->builder, "/org/freedesktop/network-manager-l2tp/nm-l2tp-dialog.ui", error)) {
 		g_object_unref(object);
 		return NULL;
 	}
-	g_free (ui_file);
 
 	priv->widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "l2tp-vbox"));
 	if (!priv->widget) {
